Concentration
=============

The objective of Concentration is to flip and match all the turned-down
cards in as few moves as possible.

.. figure:: screenshot.jpg
   :alt: Screenshot of an in-progress Concentration game

   Screenshot of an in-progress Concentration game



`Download the demo <../../_static/concentration.zip>`__.
